==> gatsby-theme-platformos-docskit-1.1.4.tgz: package/src/templates/docs.js <==
import * as React from 'react';
import { graphql } from 'gatsby';
import { MDXProvider } from '@mdx-js/react';
import Layout from '@components/layout';
import Seo from '@components/seo';
import Hero from '@components/hero';
import Button from '@components/button';
import Grid from '@components/grid';
import Card from '@components/card';
import Message from '@components/message';
import Heading from '@components/heading';
import ThemeProvider from '../theme/theme-provider';

const getHeading = (level, props) => (<Heading {...props} level={level} />);

export default function DocsTemplate({ data, children, location }) {
  // @refresh reset
  const { mdx } = data;
  const mdxComponents = {
    Hero,
    Button,
    Grid,
    Card,
    Message,
    h1: (props) => getHeading(1, props),
    h2: (props) => getHeading(2, props),
    h3: (props) => getHeading(3, props),
    h4: (props) => getHeading(4, props),
    h5: (props) => getHeading(5, props),
    h6: (props) => getHeading(6, props)
  };

  return (
    <Layout location={location} currentSlug={mdx.frontmatter.slug} sidebarEnabled={!mdx.frontmatter.hideNavigation} tocEnabled={!mdx.frontmatter.hideToc}>
      <div className="prose max-w-none prose-a:text-interactive-text">
        <MDXProvider components={mdxComponents}>{children}</MDXProvider>
      </div>
    </Layout>
  );
}

export const Head = ({ data }) => {
  const { mdx } = data;
  return (
    <>
      <Seo title={mdx.frontmatter.title} description={mdx.frontmatter.description} />
      <ThemeProvider />
    </>
  );
};

export const pageQuery = graphql`
  query($id: String!) {
    mdx(fields: { id: { eq: $id } }) {
      body
      frontmatter {
        title
        description
        slug
        hideNavigation
        hideToc
      }
    }
  }
`;

==> gatsby-theme-platformos-docskit-1.1.5.tgz: package/src/templates/docs.js <==
import * as React from 'react';
import { graphql } from 'gatsby';
import { MDXProvider } from '@mdx-js/react';
import Layout from '@components/layout';
import Seo from '@components/seo';
import Hero from '@components/hero';
import Button from '@components/button';
import Grid from '@components/grid';
import Card from '@components/card';
import Message from '@components/message';
import Heading from '@components/heading';
import ThemeProvider from '../theme/theme-provider';

const getHeading = (level, props) => (<Heading {...props} level={level} />);

export default function DocsTemplate({ data, children, location, pageContext }) {
  // @refresh reset
  const { mdx } = data;
  const { navigationTree, metaData } = pageContext;
  const mdxComponents = {
    Hero,
    Button,
    Grid,
    Card,
    Message,
    h1: (props) => getHeading(1, props),
    h2: (props) => getHeading(2, props),
    h3: (props) => getHeading(3, props),
    h4: (props) => getHeading(4, props),
    h5: (props) => getHeading(5, props),
    h6: (props) => getHeading(6, props)
  };

  return (
    <Layout
      location={location}
      currentSlug={mdx.frontmatter.slug}
      sidebarEnabled={!mdx.frontmatter.hideNavigation}
      tocEnabled={!mdx.frontmatter.hideToc}
      treeData={navigationTree}
      metaData={metaData}
    >
      <div className="prose max-w-none prose-a:text-interactive-text">
        <MDXProvider components={mdxComponents}>{children}</MDXProvider>
      </div>
    </Layout>
  );
}

export const Head = ({ data }) => {
  const { mdx, site } = data;
  return (
    <>
      <Seo title={mdx.frontmatter.title} description={mdx.frontmatter.description} meta={site?.siteMetadata} />
      <ThemeProvider />
    </>
  );
};

export const pageQuery = graphql`
  query($id: String!) {
    site {
      siteMetadata {
        title
        description
        themeConfig {
          useLegacyUrls
          showFullNavigation
        }
      }
    }
    mdx(fields: { id: { eq: $id } }) {
      body
      frontmatter {
        title
        description
        slug
        hideNavigation
        hideToc
      }
    }
  }
`;
